﻿using NUnit.Framework;
using Rhino.Mocks;
using ZipComponents;

namespace PlzSuperTool.Tests
{
    [TestFixture]
    public class ZipComponentTests
    {
        [Test]
        public void GetZip_CityIngolstadt_Get85055()
        {
            // Arrange
            ZipComponent zipComponent = new ZipComponent(new FileReader());
            
            // Act
            string[] result = zipComponent.GetZip("Ingolstadt");

            // Assert
            Assert.Contains("85055", result);
        }

        [Test]
        public void GetZip_CityIngolstadt_Get85055_Mocked()
        {
            // Arrange
            IDataReader dataReader = MockRepository.GenerateMock<IDataReader>();
            dataReader.Stub(x => x.Lines).Return(new[] { "DE	85055	Ingolstadt	Bayern	BY	Oberbayern		Kreisfreie Stadt Ingolstadt	48.776	11.4459	" });

            ZipComponent zipComponent = new ZipComponent(dataReader);

            // Act
            string[] result = zipComponent.GetZip("Ingolstadt");

            // Assert
            Assert.Contains("85055", result);
        }

        [Test]
        public void GetZip_CityPfaffenhofen_Get85276()
        {
            // Arrange
            ZipComponent zipComponent = new ZipComponent(new FileReader());

            // Act
            string[] result = zipComponent.GetZip("Pfaffenhofen");

            // Assert
            Assert.Contains("85276", result);   
        }
    }
}
